@@ -3,12 +3,11 @@
 #' This function, similar to `testthat::test_path()`, is designed to work both
 #' interactively and during tests, locating files in the `tests/` directory.
 #'
+#' @note `vcr_test_path()` assumes you are using testthat for your unit tests.
+#'
 #' @param ...	Character vectors giving path component. each character string
 #' gets added on to the path, e.g., `vcr_test_path("a", "b")` becomes
 #' `tests/a/b` relative to the root of the package.
-#' 
-#' @note Beware if you have more than one `tests` directories in your package
-#' root. This may not work as intended if that is the case.
 #'
 #' @return A character vector giving the path
 #' @export
@@ -19,8 +18,10 @@
 vcr_test_path <- function(...) {
   if (missing(...)) stop("Please provide a directory name.")
   if (any(!nzchar(...))) stop("Please use non empty path elements.")
-  root <- rprojroot::has_dir("tests")
-  path <- root$find_file("tests", ...)
+
+  # dirname () moves up one level from testthat dir
+  root <- dirname(rprojroot::find_testthat_root_file())
+  path <- file.path(root, ...)
   if (!dir.exists(path)){
     message("could not find ", path, "; creating it")
     dir.create(path)
