@@ -11,8 +11,8 @@ test_that("use_vcr works", {
   expect_null(res)
   expect_true(dir.exists(file.path(dir, "tests")))
   expect_true(file.exists(file.path(dir, "tests/testthat.R")))
-  expect_true(file.exists(file.path(dir, "tests/testthat/setup-foobar.R")))
-  help <- paste0(readLines(file.path(dir, "tests/testthat/setup-foobar.R")),
+  expect_true(file.exists(file.path(dir, "tests/testthat/helper-vcr.R")))
+  help <- paste0(readLines(file.path(dir, "tests/testthat/helper-vcr.R")),
     collapse = " ")
   expect_match(help, "vcr::vcr_configure")
   expect_match(help, "vcr::check_cassette_names")
